@@ -198,15 +198,15 @@ class GraphQLEnvironment:
     @staticmethod
     def format_query_payload_dict(data: Dict[str, Any]) -> str:
         """Formats a key-value dictionary for a query."""
-        values = []
 
-        for key, value in data.items():
-            values.append(f"{key} : {value}")
+        values = [f"{key} : {value}" for key, value in data.items()]
+        string_values = " ".join(values)
 
-        return "{ %s }" % (" ".join(values))
+        return f"{{ {string_values} }}"
 
     @staticmethod
     def format_query_selection_fields(fields: List[str]) -> str:
         """Formats a list of values for a query."""
         # e.g '{ modelId name status errors progress }'
-        return "{ %s }" % (" ".join(fields))
+        string_fields = " ".join(fields)
+        return f"{{ {string_fields} }}"
