@@ -19,6 +19,12 @@ from .get_environment import (
 )
 from .get_mutation_name import GetMutationNameQuery
 from .me import MeQuery
-from .refresh_action import RefreshActionQuery
+from .refresh_action import (
+    MultiRefreshActionQuery,
+    RefreshActionQuery,
+)
 from .refresh_token import RefreshTokenQuery
-from .start_action import StartActionQuery
+from .start_action import (
+    MultiStartActionQuery,
+    StartActionQuery,
+)
