@@ -37,5 +37,5 @@ class MeQuery(StaticQuery):  # pylint:disable=too-few-public-methods
     """
     )
 
-    def _format_response(self, response: dict) -> str:
+    def _format_response(self, response: dict, *_) -> str:
         return response["me"]["me"]["username"]
